@@ -4,10 +4,9 @@ import fleter
 
 def run():
     def main(page: flet.Page):
-        swich_theme_button = fleter.SwichThemeButton(page)
-        page.add(
-            swich_theme_button
-        )
+        headerBar = fleter.HeaderBar(page, )
+        headerBar.show()
+        headerBar.controls.insert(1, fleter.SwichThemeButton(page))
         page.update()
 
     flet.app(target=main)
